# sentry-protos python clients

This package contains the generated code from the sentry-protos project for python.

:warning: All code within `py/sentry_protos` is generated by tooling in the containing project and should not be modified by hand. :warning:

## Installation

```bash
pip install sentry-protos
```
